//+------------------------------------------------------------------+
//|                                             AutoFibAutoTrend.mq4 |
//|                                                    zzuegg        |
//|                                       when-money-makes-money.com |
//+------------------------------------------------------------------+
#property copyright "ZigZagFibAutoTrend"
#property link      ""
#property version "1.01"
/*
2024-JUL-28 v1.01  pips4life  
   In response to a request in post here:  https://www.forexfactory.com/thread/post/14945485#post14945485 
   Added 'Fib1Levels[]' array, and the Fibo levels will display both the fib-level (e.g. "23.6"), and the price at each level

*/

// The Fib1Levels can be customized, adding up to 32 possible levels (The max supported by MT4)
double Fib1Levels[] = {0.000000, 0.236068, 0.381966, 0.500000, 0.618034, 1.000000, 
                       1.618034, 2.618034, 4.236068};
int fib1count = MathMax(32, ArraySize(Fib1Levels)); 


#property indicator_chart_window
extern ENUM_TIMEFRAMES    TimeFrame  =  PERIOD_CURRENT;
input int InpDepth=12;     // Depth
input int InpDeviation=5;  // Deviation
input int InpBackstep=3;   // Backstep
extern bool ShowFib=true;
extern color FibColor=Red;
extern int   FibSize=1;

extern bool ShowFibFan=true;
extern color FibFanColor=Yellow;
extern int FibFanSize=1;

extern bool ShowTrend=true;
extern color TrendColor=Blue;
extern int TrendSize=2;

string fib1="";
string trend="";
string fibf1="";

int init()
  {
   fib1="fib1"+TimeFrame;
   trend="trend1"+TimeFrame; 
   fibf1="fibf1"+TimeFrame;  
   return(0);
  }

int deinit()
  {
   ObjectDelete(fib1);
   ObjectDelete(trend);
   ObjectDelete(fibf1);
   return(0);
  }


int start()
  {
   int    counted_bars=IndicatorCounted();
   static datetime curr=0;
   if(curr!=iTime(Symbol(),TimeFrame,0))
   {
      curr=iTime(Symbol(),TimeFrame,0);
      ObjectDelete(fib1);
      ObjectDelete(trend);
      double swing_value[4]={0,0,0,0};
      datetime swing_date[4]={0,0,0,0};
      int found=0;
      double tmp=0;
      int i=0;
      while(found<4)
      {
         if(iCustom(Symbol(),TimeFrame,"ZigZag",InpDepth,InpDeviation,InpBackstep,0,i)!=0)
         {
            swing_value[found]=iCustom(Symbol(),TimeFrame,"ZigZag",InpDepth,InpDeviation,InpBackstep,0,i);
            swing_date[found]=iTime(Symbol(),TimeFrame,i);
            found++;
         }
         i++;
      }
      ObjectDelete(trend);
      if(ShowTrend){
      ObjectCreate(trend,OBJ_CHANNEL,0,swing_date[3],swing_value[3],swing_date[1],swing_value[1],swing_date[2],swing_value[2]);
      ObjectSet(trend,OBJPROP_COLOR,TrendColor);
      ObjectSet(trend,OBJPROP_WIDTH,TrendSize);
      }
      ObjectDelete(fib1);
      if(ShowFib){
         ObjectCreate(fib1,OBJ_FIBO,0,swing_date[2],swing_value[2],swing_date[1],swing_value[1]);
         ObjectSet(fib1,OBJPROP_LEVELCOLOR,FibColor);      
         ObjectSet(fib1,OBJPROP_LEVELWIDTH,FibSize);
         //
         // Added in v1.01
         // Surprisingly, if the user did not set any specific levels, the OBJPROP_LEVELS value is actually 0.  
         // MT4 *displays* a default set of levels, and each level-text is just the basic percentage, e.g. 0.236 displays as "23.6"
         // To customize the levels and/or level-texts, one must explicitly set ALL the levels and associated level-texts as done below:
         ObjectSet(fib1, OBJPROP_LEVELS,fib1count);
         for(int j=0; j<fib1count; j++)
         {
            ObjectSet(fib1, OBJPROP_FIRSTLEVEL+j, Fib1Levels[j]);
            ObjectSetFiboDescription(fib1, j, DoubleToStr(100.0*Fib1Levels[j],1)+"  %$");  // MT4 replaces "%$" with the actual price at each level.         
         }
      }
      ObjectDelete(fibf1);
      if(ShowFibFan){
      ObjectCreate(fibf1,OBJ_FIBOFAN,0,swing_date[2],swing_value[2],swing_date[1],swing_value[1]);
      ObjectSet(fibf1,OBJPROP_LEVELCOLOR,FibFanColor);      
      ObjectSet(fibf1,OBJPROP_LEVELWIDTH,FibFanSize); 
      }
   }   

  // Comment("Support us, donate on this website: www.when-money-makes-money.com/download");
   return(0);
  }